@@ -7,6 +7,9 @@ use base 'Mojo::Base';
 
 require Carp;
 
+__PACKAGE__->attr(is_async => 0);
+__PACKAGE__->attr('error');
+
 sub create { Carp::croak('Method "create" not implemented by subbclass') }
 
 sub update { Carp::croak('Method "update" not implemented by subbclass') }
@@ -72,15 +75,4 @@ Load session. Returns $expire and $data values.
 
 Delete session. Returns status.
 
-=head1 AUTHOR
-
-vti, C<vti@cpan.org>.
-
-=head1 COPYRIGHT
-
-Copyright (C) 2008, Viacheslav Tikhanovskii.
-
-This program is free software, you can redistribute it and/or modify it under
-the same terms as Perl 5.10.
-
 =cut
