@@ -6,10 +6,8 @@ use warnings;
 use base 'Mojo::Base';
 
 require Carp;
-use Mojo::Transaction;
 
-__PACKAGE__->attr(
-    tx => (weak => 1, chained => 1, default => sub { Mojo::Transaction->new }));
+__PACKAGE__->attr('tx');
 
 sub get { Carp::croak('Method "get" not implemented by subbclass') }
 
@@ -53,17 +51,4 @@ Get session id. Returns it.
 
 Set session id. Returns status.
 
-=head2 C<load>
-
-=head1 AUTHOR
-
-vti, C<vti@cpan.org>.
-
-=head1 COPYRIGHT
-
-Copyright (C) 2008, Viacheslav Tikhanovskii.
-
-This program is free software, you can redistribute it and/or modify it under
-the same terms as Perl 5.10.
-
 =cut
